## $Id: interfaces.py 14022 2016-07-07 06:45:09Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
from zope.interface import Attribute, Interface
from zope import schema
from waeup.ikoba.interfaces import (
    IIkobaObject, validate_id,
    ContextualDictSourceFactoryBase)
from waeup.ikoba.schema import FormattedDate
from waeup.ikoba.interfaces import MessageFactory as _
from waeup.ikoba.products.productoptions import ProductOptionField

class ConCatSource(ContextualDictSourceFactoryBase):
    """A contract category source delivers all contract categories
    provided in the portal.
    """
    #: name of dict to deliver from kofa utils.
    DICT_NAME = 'CON_CATS_DICT'

class IProductsContainer(IIkobaObject):
    """A container for all kind of product objects.

    """

    description_dict = Attribute(
        'Description as language dictionary with values in html format')

    description = schema.Text(
        title = _(u'Description'),
        required = False,
        description = _(u'Multilingual content in HTML format'),
        )

    def addProduct(product):
        """Add a product.
        """

class IProduct(IIkobaObject):
    """A base representation of products.

    """
    product_id = schema.TextLine(
        title = _(u'Product Id'),
        default = u'NA',
        required = True,
        constraint=validate_id,
        )

    title = schema.TextLine(
        title = _(u'Product Title'),
        required = True,
        default = u'Unnamed',
        )

    contract_title = schema.TextLine(
        title = _(u'Contract Title'),
        description = _('Product title is used if empty.'),
        required = False,
        )

    contract_category = schema.Choice(
        title = _(u'Contract Category'),
        source = ConCatSource(),
        required = True,
        )

    options = schema.List(
        title = _(u'Options/Fees'),
        value_type = ProductOptionField(),
        required = False,
        readonly = False,
        defaultFactory=list,
        )

    valid_from = FormattedDate(
        title = _(u'Valid from'),
        required = False,
        show_year = True,
        )

    valid_to = FormattedDate(
        title = _(u'Valid to'),
        required = False,
        show_year = True,
        )

    description_dict = Attribute(
        'Description as language dictionary with values in html format')

    description = schema.Text(
        title = _(u'Description'),
        required = False,
        description = _(u'Multilingual content in HTML format'),
        )

    tc_dict = Attribute('Terms and Conditions as language dictionary with values in html format')

    terms_and_conditions = schema.Text(
        title = _(u'Terms and Conditions'),
        required = False,
        description = _(u'Multilingual content in HTML format'),
        )